@@ -117,9 +117,9 @@ plot.adjustedsurv <- function(x, conf_int=FALSE, max_t=Inf,
   p <- ggplot2::ggplot(plotdata, mapping)
 
   if (steps) {
-    line_obj <- ggplot2::geom_step(size=line_size, alpha=line_alpha)
+    line_obj <- ggplot2::geom_step(linewidth=line_size, alpha=line_alpha)
   } else {
-    line_obj <- ggplot2::geom_line(size=line_size, alpha=line_alpha)
+    line_obj <- ggplot2::geom_line(linewidth=line_size, alpha=line_alpha)
   }
 
   # override color using just one color
@@ -252,7 +252,7 @@ plot.adjustedsurv <- function(x, conf_int=FALSE, max_t=Inf,
                                        shape=censoring_ind_shape)
     } else if (censoring_ind=="lines") {
       cens_geom <- ggplot2::geom_segment(data=cens_dat, cens_map,
-                                         size=censoring_ind_size,
+                                         linewidth=censoring_ind_size,
                                          alpha=censoring_ind_alpha)
     }
 
@@ -358,7 +358,7 @@ plot.adjustedsurv <- function(x, conf_int=FALSE, max_t=Inf,
                                                   yend=.data$vert_yend),
                                      inherit.aes=FALSE,
                                      linetype=median_surv_linetype,
-                                     size=median_surv_size,
+                                     linewidth=median_surv_size,
                                      color=median_surv_color,
                                      alpha=median_surv_alpha,
                                      data=median_surv)
@@ -369,7 +369,7 @@ plot.adjustedsurv <- function(x, conf_int=FALSE, max_t=Inf,
                                                   yend=.data$yend),
                                      inherit.aes=FALSE,
                                      linetype=median_surv_linetype,
-                                     size=median_surv_size,
+                                     linewidth=median_surv_size,
                                      color=median_surv_color,
                                      alpha=median_surv_alpha,
                                      data=median_surv)
